@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from dateutil.parser import parse
 from pendulum import parse as strict_parse
 from pendulum.exceptions import ParserError
 
@@ -10,11 +9,8 @@ def num_digits(s: str):
 
 
 def guess_type(s: str):
-    """Guess datetime data type for input string. Supports ISO 8601. 
-
+    """Guess datetime data type for input string. Supports ISO 8601.
     Uses pendulum parser to determine if input is valid date(time).
-    Due to pendulum including tzinfo in all datetime objects, dateutil parser is used
-    to determine if TZ is included.
     """
 
     n = num_digits(s)
@@ -30,15 +26,8 @@ def guess_type(s: str):
     except ParserError:
         return None
 
-    # detect date
     if n == 8:
         dtype = "DATE"
     else:
-        dt = parse(s)
-
-        if dt.tzinfo:
-            dtype = "TIMESTAMPTZ"
-        else:
-            dtype = "TIMESTAMP"
-
+        dtype = "TIMESTAMP"
     return dtype
